package TestApp::Controller::Account;

use strict;
use warnings;
use base 'Catalyst::Controller::SingletonResource';

sub post {}
sub create {}
sub show {}
sub update {}
sub destroy {}
sub edit {}

1;
